@@ -109,7 +109,15 @@ my %supportedFilter = (
     Title       => { },
     Author      => { Groups => { 2 => 'Author' } },
     Subject     => { },
-    Keywords    => { List => 'string' },  # this is a string list
+    Keywords    => {
+        List => 'string',  # this is a string list
+        Notes => q{
+            stored as a string but treated as a comma-separated list of items when
+            reading if the string contains a comma, otherwise a space-separated list of
+            items.  Written as a comma-separated list.  The list behaviour may be
+            defeated by setting the API NoPDFList option
+        },
+    },
     Creator     => { },
     Producer    => { },
     CreationDate => {
@@ -2393,8 +2401,8 @@ This module is loaded automatically by Image::ExifTool when required.
 This code reads meta information from PDF (Adobe Portable Document Format)
 files.  It supports object streams introduced in PDF-1.5 but only with a
 limited set of Filter and Predictor algorithms, however all standard
-encryption methods through PDF-1.7 extension level 3 are supported,
-including AESV2 (AES-128) and AESV3 (AES-256).
+encryption methods through PDF-2.0 are supported, including AESV2 (AES-128)
+and AESV3 (AES-256).
 
 =head1 AUTHOR
 
